 README.md                                          |  4 +--
 config/schema/entity_embed.schema.yml              |  4 +--
 entity_embed.api.php                               |  7 +++--
 src/Annotation/EntityEmbedDisplay.php              | 19 +++++++++----
 src/EntityEmbedDisplay/EntityEmbedDisplayBase.php  | 12 ++++++--
 .../EntityEmbedDisplayInterface.php                | 18 ++++++++----
 .../EntityEmbedDisplayManager.php                  |  6 ++--
 .../FieldFormatterEntityEmbedDisplayBase.php       |  3 +-
 src/EntityHelperTrait.php                          | 32 +++++++++++-----------
 src/Form/EntityEmbedDialog.php                     | 21 +++++++-------
 src/Plugin/Derivative/FieldFormatterDeriver.php    |  7 +++--
 src/Plugin/EmbedType/Entity.php                    | 13 +++++----
 .../EntityEmbedDisplay/ImageFieldFormatter.php     | 10 +++----
 src/Tests/EntityEmbedDialogTest.php                |  2 +-
 src/Tests/EntityEmbedFilterTest.php                |  6 ++--
 src/Tests/EntityEmbedTwigTest.php                  |  4 +--
 src/Tests/EntityReferenceFieldFormatterTest.php    | 14 +++++-----
 src/Tests/FileFieldFormatterTest.php               |  4 +--
 src/Tests/ImageFieldFormatterTest.php              |  4 +--
 src/Twig/EntityEmbedTwigExtension.php              |  5 ++--
 .../src/EntityEmbedTestTwigController.php          |  4 +--
 .../templates/entity_embed_twig_test.html.twig     |  5 ++--
 22 files changed, 117 insertions(+), 87 deletions(-)

diff --git a/README.md b/README.md
index db06db2..56d1a71 100644
--- a/README.md
+++ b/README.md
@@ -55,13 +55,13 @@ Users should be embedding entities using the CKEditor WYSIWYG button as describe
 
 ### Entity Embed Display Plugins
 
-Embedding entities uses an entity embed display plugin, provided in the `data-entity-embed-display` attribute. By default we provide four different display plugins out of the box:
+Embedding entities uses an Entity Embed Display plugin, provided in the `data-entity-embed-display` attribute. By default we provide four different Entity Embed Display plugins out of the box:
 
 - entity_reference:_formatter_id_: Renders the entity using a specific Entity Reference field formatter.
 - entity_reference:_entity_reference_label_: Renders the entity using the "Label" formatter.
 - file:_formatter_id_: Renders the entity using a specific File field formatter. This will only work if the entity is a file entity type.
 - image:_formatter_id_: Renders the entity using a specific Image field formatter. This will only work if the entity is a file entity type, and the file is an image.
 
-Configuration for the display plugin can be provided by using a `data-entity-embed-settings` attribute, which contains a JSON-encoded array value. Note that care must be used to use single quotes around the attribute value since JSON-encoded arrays typically contain double quotes.
+Configuration for the Entity Embed Display plugin can be provided by using a `data-entity-embed-settings` attribute, which contains a JSON-encoded array value. Note that care must be used to use single quotes around the attribute value since JSON-encoded arrays typically contain double quotes.
 
 The above examples render the entity using the _entity_reference_entity_view_ formatter from the Entity Reference module, using the _teaser_ view mode.
diff --git a/config/schema/entity_embed.schema.yml b/config/schema/entity_embed.schema.yml
index 02a8f8f..0f6aaec 100644
--- a/config/schema/entity_embed.schema.yml
+++ b/config/schema/entity_embed.schema.yml
@@ -15,10 +15,10 @@ embed.embed_type_settings.entity:
         label: 'Bundle'
     display_plugins:
       type: sequence
-      label: 'Allowed display plugins'
+      label: 'Allowed Entity Embed Display plugins'
       sequence:
         type: string
-        label: 'Display plugin'
+        label: 'Entity Embed Display plugin'
     entity_browser:
       type: string
       label: 'Entity browser'
diff --git a/entity_embed.api.php b/entity_embed.api.php
index f420eb8..fa762ad 100644
--- a/entity_embed.api.php
+++ b/entity_embed.api.php
@@ -11,7 +11,7 @@
  */
 
 /**
- * Alter the display plugin definitions.
+ * Alter the Entity Embed Display plugin definitions.
  *
  * @param array &$info
  *   An associative array containing the plugin definitions keyed by plugin ID.
@@ -21,9 +21,10 @@ function hook_entity_embed_display_plugins_alter(array &$info) {
 }
 
 /**
- * Alter the display plugin definitions for a given context.
+ * Alter the Entity Embed Display plugin definitions for a given context.
  *
- * Usually used to remove certain display plugins for specific entities.
+ * Usually used to remove certain Entity Embed Display plugins for specific
+ * entities.
  *
  * @param array &$definitions
  *   Remove options from this list if they should not be available for the given
diff --git a/src/Annotation/EntityEmbedDisplay.php b/src/Annotation/EntityEmbedDisplay.php
index 03fa2fd..8fe8d63 100644
--- a/src/Annotation/EntityEmbedDisplay.php
+++ b/src/Annotation/EntityEmbedDisplay.php
@@ -10,7 +10,16 @@ namespace Drupal\entity_embed\Annotation;
 use Drupal\Component\Annotation\Plugin;
 
 /**
- * Defines an entity embed display annotation object.
+ * Defines an Entity Embed Display plugin annotation object.
+ *
+ * Plugin Namespace: Plugin/entity_embed/EntityEmbedDisplay.
+ *
+ * For a working example, see \Drupal\entity_embed\Plugin\entity_embed\EntityEmbedDisplay\FileFieldFormatter
+ *
+ * @see \Drupal\entity_embed\EntityEmbedDisplay\EntityEmbedDisplayBase
+ * @see \Drupal\entity_embed\EntityEmbedDisplay\EntityEmbedDisplayInterface
+ * @see \Drupal\entity_embed\EntityEmbedDisplay\EntityEmbedDisplayManager
+ * @see plugin_api
  *
  * @ingroup entity_embed_api
  *
@@ -26,7 +35,7 @@ class EntityEmbedDisplay extends Plugin {
   public $id;
 
   /**
-   * The human-readable name of the display plugin.
+   * The human-readable name of the Entity Embed Display plugin.
    *
    * @ingroup plugin_translatable
    *
@@ -35,10 +44,10 @@ class EntityEmbedDisplay extends Plugin {
   public $label = '';
 
   /**
-   * The entity types the display can apply to.
+   * The entity types the Entity Embed Display plugin can apply to.
    *
-   * To make the display plugin valid for all entity types, set this value to
-   * FALSE.
+   * To make the Entity Embed Display plugin valid for all entity types, set
+   * this value to FALSE.
    *
    * @var bool|array
    */
diff --git a/src/EntityEmbedDisplay/EntityEmbedDisplayBase.php b/src/EntityEmbedDisplay/EntityEmbedDisplayBase.php
index 22e7cde..2e6ef49 100644
--- a/src/EntityEmbedDisplay/EntityEmbedDisplayBase.php
+++ b/src/EntityEmbedDisplay/EntityEmbedDisplayBase.php
@@ -18,9 +18,14 @@ use Drupal\entity_embed\EntityHelperTrait;
 use Symfony\Component\DependencyInjection\ContainerInterface;
 
 /**
- * Defines a base display implementation that most display plugins will extend.
+ * Defines a base Entity Embed Display implementation.
  *
- * @ingroup entity_embed_api
+ * @see \Drupal\entity_embed\Annotation\EntityEmbedDisplay
+ * @see \Drupal\entity_embed\EntityEmbedDisplay\EntityEmbedDisplayInterface
+ * @see \Drupal\entity_embed\EntityEmbedDisplay\EntityEmbedDisplayManager
+ * @see plugin_api
+ *
+  * @ingroup entity_embed_api
  */
 abstract class EntityEmbedDisplayBase extends PluginBase implements ContainerFactoryPluginInterface, EntityEmbedDisplayInterface {
   use EntityHelperTrait;
@@ -84,7 +89,8 @@ abstract class EntityEmbedDisplayBase extends PluginBase implements ContainerFac
   }
 
   /**
-   * Validates that this display plugin applies to the current entity type.
+   * Validates that this Entity Embed Display plugin applies to the current
+   * entity type.
    *
    * This checks the plugin annotation's 'entity_types' value, which should be
    * an array of entity types that this plugin can process, or FALSE if the
diff --git a/src/EntityEmbedDisplay/EntityEmbedDisplayInterface.php b/src/EntityEmbedDisplay/EntityEmbedDisplayInterface.php
index 1555cb5..e7d63a6 100644
--- a/src/EntityEmbedDisplay/EntityEmbedDisplayInterface.php
+++ b/src/EntityEmbedDisplay/EntityEmbedDisplayInterface.php
@@ -13,28 +13,34 @@ use Drupal\Core\Plugin\PluginFormInterface;
 use Drupal\Core\Session\AccountInterface;
 
 /**
- * Defines the required interface for all entity embed display plugins.
+ * Defines the interface for Entity Embed Display plugins.
+ *
+ * @see \Drupal\entity_embed\Annotation\EntityEmbedDisplay
+ * @see \Drupal\entity_embed\EntityEmbedDisplay\EntityEmbedDisplayBase
+ * @see \Drupal\entity_embed\EntityEmbedDisplay\EntityEmbedDisplayManager
+ * @see plugin_api
  *
  * @ingroup entity_embed_api
  */
 interface EntityEmbedDisplayInterface extends ConfigurablePluginInterface, PluginFormInterface, PluginInspectionInterface {
 
   /**
-   * Indicates whether the entity embed display can be used.
+   * Indicates whether this Entity Embed display can be used.
    *
    * This method allows base implementations to add general access restrictions
-   * that should apply to all extending entity embed display plugins.
+   * that should apply to all extending Entity Embed display plugins.
    *
    * @param \Drupal\Core\Session\AccountInterface $account
-   *   The user session for which to check access.
+   *   (optional) The user for which to check access, or NULL to check access
+   *   for the current user. Defaults to NULL.
    *
    * @return bool
-   *   TRUE if this entity embed display plugin can be used, or FALSE otherwise.
+   *   TRUE if this Entity Embed Display plugin can be used, or FALSE otherwise.
    */
   public function access(AccountInterface $account = NULL);
 
   /**
-   * Builds and returns the renderable array for this display plugin.
+   * Builds the renderable array for this Entity Embed display plugin.
    *
    * @return array
    *   A renderable array representing the content of the embedded entity.
diff --git a/src/EntityEmbedDisplay/EntityEmbedDisplayManager.php b/src/EntityEmbedDisplay/EntityEmbedDisplayManager.php
index f3a28fa..62bfc01 100644
--- a/src/EntityEmbedDisplay/EntityEmbedDisplayManager.php
+++ b/src/EntityEmbedDisplay/EntityEmbedDisplayManager.php
@@ -14,15 +14,17 @@ use Drupal\Core\Plugin\DefaultPluginManager;
 use Drupal\Component\Plugin\Exception\PluginException;
 
 /**
- * Provides an Entity embed display plugin manager.
+ * Provides an Entity Embed display plugin manager.
  *
  * @see \Drupal\entity_embed\Annotation\EntityEmbedDisplay
+ * @see \Drupal\entity_embed\EntityEmbedDisplay\EntityEmbedDisplayBase
  * @see \Drupal\entity_embed\EntityEmbedDisplay\EntityEmbedDisplayInterface
+ * @see plugin_api
  */
 class EntityEmbedDisplayManager extends DefaultPluginManager {
 
   /**
-   * Constructs a new class instance.
+   * Constructs a new EntityEmbedDisplayManager.
    *
    * @param \Traversable $namespaces
    *   An object that implements \Traversable which contains the root paths
diff --git a/src/EntityEmbedDisplay/FieldFormatterEntityEmbedDisplayBase.php b/src/EntityEmbedDisplay/FieldFormatterEntityEmbedDisplayBase.php
index d18ce4c..79456c2 100644
--- a/src/EntityEmbedDisplay/FieldFormatterEntityEmbedDisplayBase.php
+++ b/src/EntityEmbedDisplay/FieldFormatterEntityEmbedDisplayBase.php
@@ -92,7 +92,8 @@ abstract class FieldFormatterEntityEmbedDisplayBase extends EntityEmbedDisplayBa
     if (!isset($this->fieldDefinition)) {
       $field_type = $this->getPluginDefinition()['field_type'];
       $this->fieldDefinition = BaseFieldDefinition::create($field_type);
-      // Ensure the field name is unique for each display plugin instance.
+      // Ensure the field name is unique for each Entity Embed Display plugin
+      // instance.
       static $index = 0;
       $this->fieldDefinition->setName('_entity_embed_' . $index++);
     }
diff --git a/src/EntityHelperTrait.php b/src/EntityHelperTrait.php
index 13ac880..3f667ac 100644
--- a/src/EntityHelperTrait.php
+++ b/src/EntityHelperTrait.php
@@ -39,7 +39,7 @@ trait EntityHelperTrait {
   protected $moduleHandler;
 
   /**
-   * The display plugin manager.
+   * The Entity Embed Display plugin manager.
    *
    * @var \Drupal\entity_embed\EntityEmbedDisplay\EntityEmbedDisplayManager.
    */
@@ -159,7 +159,7 @@ trait EntityHelperTrait {
    *   the embed HTML tag.
    *
    * @return string
-   *   The HTML of the entity rendered with the display plugin.
+   *   The HTML of the entity rendered with the Entity Embed Display plugin.
    */
   protected function renderEntityEmbed(EntityInterface $entity, array $context = array()) {
     // Support the deprecated view-mode data attribute.
@@ -176,8 +176,8 @@ trait EntityHelperTrait {
       'data-entity-embed-settings' => array(),
     );
 
-    // The default display plugin has been deprecated by the rendered entity
-    // field formatter.
+    // The default Entity Embed Display plugin has been deprecated by the
+    // rendered entity field formatter.
     if ($context['data-entity-embed-display'] === 'default') {
       $context['data-entity-embed-display'] = 'entity_reference:entity_reference_entity_view';
     }
@@ -185,8 +185,8 @@ trait EntityHelperTrait {
     // Allow modules to alter the entity prior to embed rendering.
     $this->moduleHandler()->alter(array("{$context['data-entity-type']}_embed_context", 'entity_embed_context'), $context, $entity);
 
-    // Build and render the display plugin, allowing modules to alter the
-    // result before rendering.
+    // Build and render the Entity Embed Display plugin, allowing modules to
+    // alter the result before rendering.
     $build = $this->renderEntityEmbedDisplayPlugin(
       $entity,
       $context['data-entity-embed-display'],
@@ -201,12 +201,12 @@ trait EntityHelperTrait {
   }
 
   /**
-   * Renders an entity using an EntityEmbedDisplay plugin.
+   * Renders an entity using an Entity Embed Display plugin.
    *
    * @param \Drupal\Core\Entity\EntityInterface $entity
    *   The entity to be rendered.
    * @param string $plugin_id
-   *   The EntityEmbedDisplay plugin ID.
+   *   The Entity Embed Display plugin ID.
    * @param array $plugin_configuration
    *   (optional) Array of plugin configuration values.
    * @param array $context
@@ -214,17 +214,17 @@ trait EntityHelperTrait {
    *   tag's attributes.
    *
    * @return array
-   *   A render array for the display plugin.
+   *   A render array for the Entity Embed Display plugin.
    */
   protected function renderEntityEmbedDisplayPlugin(EntityInterface $entity, $plugin_id, array $plugin_configuration = array(), array $context = array()) {
-    // Build the display plugin.
+    // Build the Entity Embed Display plugin.
     /** @var \Drupal\entity_embed\EntityEmbedDisplay\EntityEmbedDisplayBase $display */
     $display = $this->displayPluginManager()->createInstance($plugin_id, $plugin_configuration);
     $display->setContextValue('entity', $entity);
     $display->setAttributes($context);
 
-    // Check if the display plugin is accessible. This also checks entity
-    // access, which is why we never call $entity->access() here.
+    // Check if the Entity Embed Display plugin is accessible. This also checks
+    // entity access, which is why we never call $entity->access() here.
     if (!$display->access()) {
       return array();
     }
@@ -285,10 +285,10 @@ trait EntityHelperTrait {
   }
 
   /**
-   * Returns the display plugin manager.
+   * Returns the Entity Embed Display plugin manager.
    *
    * @return \Drupal\entity_embed\EntityEmbedDisplay\EntityEmbedDisplayManager
-   *   The display plugin manager.
+   *   The Entity Embed Display plugin manager.
    */
   protected function displayPluginManager() {
     if (!isset($this->displayPluginManager)) {
@@ -298,10 +298,10 @@ trait EntityHelperTrait {
   }
 
   /**
-   * Sets the display plugin manager service.
+   * Sets the Entity Embed Display plugin manager service.
    *
    * @param \Drupal\entity_embed\EntityEmbedDisplay\EntityEmbedDisplayManager $display_plugin_manager
-   *   The display plugin manager service.
+   *   The Entity Embed Display plugin manager service.
    *
    * @return self
    */
diff --git a/src/Form/EntityEmbedDialog.php b/src/Form/EntityEmbedDialog.php
index 625dfcd..ab37fa8 100644
--- a/src/Form/EntityEmbedDialog.php
+++ b/src/Form/EntityEmbedDialog.php
@@ -367,7 +367,7 @@ class EntityEmbedDialog extends FormBase {
       '#value' => $entity_element['data-entity-uuid'],
     );
 
-    // Build the list of allowed display plugins.
+    // Build the list of allowed Entity Embed Display plugins.
     $display_plugin_options = $this->getDisplayPluginOptions($embed_button, $entity);
 
     // If the currently selected display is not in the available options,
@@ -377,8 +377,8 @@ class EntityEmbedDialog extends FormBase {
       $entity_element['data-entity-embed-display'] = key($display_plugin_options);
     }
 
-    // The default display plugin has been deprecated by the rendered entity
-    // field formatter.
+    // The default Entity Embed Display plugin has been deprecated by the
+    // rendered entity field formatter.
     if ($entity_element['data-entity-embed-display'] === 'default') {
       $entity_element['data-entity-embed-display'] = 'entity_reference:entity_reference_entity_view';
     }
@@ -511,15 +511,15 @@ class EntityEmbedDialog extends FormBase {
             $form_state->setValueForElement($form['attributes']['data-entity-uuid'], '');
           }
 
-          // Ensure that at least one display plugin is present before
-          // proceeding to the next step. Rasie an error otherwise.
+          // Ensure that at least one Entity Embed Display plugin is present
+          // before proceeding to the next step. Rasie an error otherwise.
           $embed_button = $form_state->get('embed_button');
           $display_plugin_options = $this->getDisplayPluginOptions($embed_button, $entity);
           // If no plugin is available after taking the intersection,
           // raise error. Also log an exception.
           if (empty($display_plugin_options)) {
             $form_state->setError($form['attributes']['data-entity-id'], $this->t('No display options available for the selected entity. Please select another entity.'));
-            $this->logger('entity_embed')->warning('No display options available for "@type:" entity "@id" while embedding using button "@button". Please ensure that at least one display plugin is allowed for this embed button which is available for this entity.', array('@type' => $entity_type, '@id' => $entity->id(), '@button' => $embed_button->id()));
+            $this->logger('entity_embed')->warning('No display options available for "@type:" entity "@id" while embedding using button "@button". Please ensure that at least one Entity Embed Display plugin is allowed for this embed button which is available for this entity.', array('@type' => $entity_type, '@id' => $entity->id(), '@button' => $embed_button->id()));
           }
         }
       }
@@ -538,7 +538,7 @@ class EntityEmbedDialog extends FormBase {
    *   The current state of the form.
    */
   public function validateEmbedStep(array $form, FormStateInterface $form_state) {
-    // Validate configuration forms for the display plugin used.
+    // Validate configuration forms for the Entity Embed Display plugin used.
     $entity_element = $form_state->getValue('attributes');
     $entity = $this->loadEntity($entity_element['data-entity-type'], $entity_element['data-entity-uuid']);
     $plugin_id = $entity_element['data-entity-embed-display'];
@@ -691,7 +691,7 @@ class EntityEmbedDialog extends FormBase {
   public function submitEmbedStep(array &$form, FormStateInterface $form_state) {
     $response = new AjaxResponse();
 
-    // Submit configuration form the selected display plugin.
+    // Submit configuration form the selected Entity Embed Display plugin.
     $entity_element = $form_state->getValue('attributes');
     $entity = $this->loadEntity($entity_element['data-entity-type'], $entity_element['data-entity-uuid']);
     $plugin_id = $entity_element['data-entity-embed-display'];
@@ -725,7 +725,8 @@ class EntityEmbedDialog extends FormBase {
   }
 
   /**
-   * Returns the allowed display plugins given an embed button and an entity.
+   * Returns the allowed Entity Embed Display plugins given an embed button and
+   * an entity.
    *
    * @param \Drupal\embed\EmbedButtonInterface $embed_button
    *   The embed button.
@@ -733,7 +734,7 @@ class EntityEmbedDialog extends FormBase {
    *   The entity.
    *
    * @return array
-   *   List of allowed display plugins.
+   *   List of allowed Entity Embed Display plugins.
    */
   public function getDisplayPluginOptions(EmbedButtonInterface $embed_button, EntityInterface $entity) {
     $plugins = $this->displayPluginManager->getDefinitionOptionsForEntity($entity);
diff --git a/src/Plugin/Derivative/FieldFormatterDeriver.php b/src/Plugin/Derivative/FieldFormatterDeriver.php
index 350c50c..ccc759b 100644
--- a/src/Plugin/Derivative/FieldFormatterDeriver.php
+++ b/src/Plugin/Derivative/FieldFormatterDeriver.php
@@ -13,7 +13,7 @@ use Symfony\Component\DependencyInjection\ContainerInterface;
 use Drupal\Core\Field\FormatterPluginManager;
 
 /**
- * Provides entity embed display plugin definitions for field formatters.
+ * Provides Entity Embed Display plugin definitions for field formatters.
  *
  * @see \Drupal\entity_embed\FieldFormatterEntityEmbedDisplayBase
  */
@@ -50,10 +50,11 @@ class FieldFormatterDeriver extends DeriverBase implements ContainerDeriverInter
    *
    * @throws \LogicException
    *   Throws an exception if field type is not defined in the annotation of the
-   *   display plugin.
+   *   Entity Embed Display plugin.
    */
   public function getDerivativeDefinitions($base_plugin_definition) {
-    // The field type must be defined in the annotation of the display plugin.
+    // The field type must be defined in the annotation of the Entity Embed
+    // Display plugin.
     if (!isset($base_plugin_definition['field_type'])) {
       throw new \LogicException("Undefined field_type definition in plugin {$base_plugin_definition['id']}.");
     }
diff --git a/src/Plugin/entity_embed/EntityEmbedDisplay/ImageFieldFormatter.php b/src/Plugin/entity_embed/EntityEmbedDisplay/ImageFieldFormatter.php
index e44eb9a..d701498 100644
--- a/src/Plugin/entity_embed/EntityEmbedDisplay/ImageFieldFormatter.php
+++ b/src/Plugin/entity_embed/EntityEmbedDisplay/ImageFieldFormatter.php
@@ -122,11 +122,11 @@ class ImageFieldFormatter extends FileFieldFormatter {
     $alt = $this->getAttributeValue('alt', '');
     if ($alt === '') {
       // Do not change empty alt text to two double quotes if the previously
-      // used display plugin was not 'image:image'. That means that some other
-      // plugin was used so if this image formatter is selected at a later
-      // stage, then this should be treated as a new edit. We show two double
-      // quotes in place of empty alt text only if that was filled intentionally
-      // by the user.
+      // used Entity Embed Display plugin was not 'image:image'. That means that
+      // some other plugin was used so if this image formatter is selected at a
+      // later stage, then this should be treated as a new edit. We show two
+      // double quotes in place of empty alt text only if that was filled
+      // intentionally by the user.
       if (!empty($entity_element) && $entity_element['data-entity-embed-display'] == 'image:image') {
         $alt = '""';
       }
diff --git a/src/Tests/EntityEmbedDialogTest.php b/src/Tests/EntityEmbedDialogTest.php
index 8ecf42e..2d2ecce 100644
--- a/src/Tests/EntityEmbedDialogTest.php
+++ b/src/Tests/EntityEmbedDialogTest.php
@@ -57,7 +57,7 @@ class EntityEmbedDialogTest extends EntityEmbedTestBase {
     // $edit = ['attributes[data-entity-id]' => $this->node->id()];
     // $this->drupalPostAjaxForm(NULL, $edit, 'op');
     // Ensure form structure of the 'embed' step and submit form.
-    // $this->assertFieldByName('attributes[data-entity-embed-display]', 'Display plugin field is present.');
+    // $this->assertFieldByName('attributes[data-entity-embed-display]', 'Entity Embed Display plugin field is present.');
   }
 
   /**
diff --git a/src/Tests/EntityEmbedFilterTest.php b/src/Tests/EntityEmbedFilterTest.php
index 177bda4..27ff46f 100644
--- a/src/Tests/EntityEmbedFilterTest.php
+++ b/src/Tests/EntityEmbedFilterTest.php
@@ -70,7 +70,7 @@ class EntityEmbedFilterTest extends EntityEmbedTestBase {
     $this->assertNoText($sample_node->body->value, 'Entity specifed with ID does not exists in the page.');
     $this->assertNoText(strip_tags($content), 'Placeholder does not appear in the output when embed is successful.');
 
-    // Test entity embed using deprecated 'default' display plugin.
+    // Test deprecated 'default' Entity Embed Display plugin.
     $content = '<div data-entity-type="node" data-entity-uuid="' . $this->node->uuid() . '" data-entity-embed-display="default" data-entity-embed-settings=\'{"view_mode":"teaser"}\'>This placeholder should not be rendered.</div>';
     $settings = array();
     $settings['type'] = 'page';
@@ -81,8 +81,8 @@ class EntityEmbedFilterTest extends EntityEmbedTestBase {
     $this->assertText($this->node->body->value, 'Embedded node exists in page.');
     $this->assertNoText(strip_tags($content), 'Placeholder does not appear in the output when embed is successful.');
 
-    // Ensure that display plugin is preferred over view mode when both
-    // attributes are present.
+    // Ensure that Entity Embed Display plugin is preferred over view mode when
+    // both attributes are present.
     $content = '<div data-entity-type="node" data-entity-uuid="' . $this->node->uuid() . '" data-entity-embed-display="default" data-entity-embed-settings=\'{"view_mode":"teaser"}\' data-view-mode="some-invalid-view-mode">This placeholder should not be rendered.</div>';
     $settings = array();
     $settings['type'] = 'page';
diff --git a/src/Tests/EntityEmbedTwigTest.php b/src/Tests/EntityEmbedTwigTest.php
index ca03736..291dc47 100644
--- a/src/Tests/EntityEmbedTwigTest.php
+++ b/src/Tests/EntityEmbedTwigTest.php
@@ -41,13 +41,13 @@ class EntityEmbedTwigTest extends EntityEmbedTestBase {
     $this->drupalGet('entity_embed_twig_test/id');
     $this->assertText($this->node->body->value, 'Embedded node exists in page');
 
-    // Test embedding using 'Label' display plugin.
+    // Test 'Label' Entity Embed Display plugin.
     $this->drupalGet('entity_embed_twig_test/label_plugin');
     $this->assertText($this->node->title->value, 'Title of the embedded node exists in page.');
     $this->assertNoText($this->node->body->value, 'Body of embedded node does not exists in page when "Label" plugin is used.');
     $this->assertLinkByHref('node/' . $this->node->id(), 0, 'Link to the embedded node exists when "Label" plugin is used.');
 
-    // Test embedding using 'Label' display plugin without linking to the node.
+    // Test 'Label' Entity Embed Display plugin without linking to the node.
     $this->drupalGet('entity_embed_twig_test/label_plugin_no_link');
     $this->assertText($this->node->title->value, 'Title of the embedded node exists in page.');
     $this->assertNoText($this->node->body->value, 'Body of embedded node does not exists in page when "Label" plugin is used.');
diff --git a/src/Tests/EntityReferenceFieldFormatterTest.php b/src/Tests/EntityReferenceFieldFormatterTest.php
index ae75588..eee67cd 100644
--- a/src/Tests/EntityReferenceFieldFormatterTest.php
+++ b/src/Tests/EntityReferenceFieldFormatterTest.php
@@ -84,14 +84,14 @@ class EntityReferenceFieldFormatterTest extends EntityEmbedTestBase {
   }
 
   /**
-   * Tests entity embed filter using entity reference display plugins.
+   * Tests filter using entity reference Entity Embed Display plugins.
    */
   public function testFilterEntityReferencePlugins() {
-    // Test entity embed using 'Label' display plugin.
+    // Test 'Label' Entity Embed Display plugin.
     $content = '<div data-entity-type="node" data-entity-uuid="' . $this->node->uuid() . '" data-entity-embed-display="entity_reference:entity_reference_label" data-entity-embed-settings=\'{"link":1}\'>This placeholder should not be rendered.</div>';
     $settings = array();
     $settings['type'] = 'page';
-    $settings['title'] = 'Test entity embed with entity_reference:entity_reference_label display plugin';
+    $settings['title'] = 'Test entity_reference:entity_reference_label Entity Embed Display plugin';
     $settings['body'] = array(array('value' => $content, 'format' => 'custom_format'));
     $node = $this->drupalCreateNode($settings);
     $this->drupalGet('node/' . $node->id());
@@ -100,11 +100,11 @@ class EntityReferenceFieldFormatterTest extends EntityEmbedTestBase {
     $this->assertNoText(strip_tags($content), 'Placeholder does not appears in the output when embed is successful.');
     $this->assertLinkByHref('node/' . $this->node->id(), 0, 'Link to the embedded node exists.');
 
-    // Test entity embed using 'Entity ID' display plugin.
+    // Test 'Entity ID' Entity Embed Display plugin.
     $content = '<div data-entity-type="node" data-entity-uuid="' . $this->node->uuid() . '" data-entity-embed-display="entity_reference:entity_reference_entity_id">This placeholder should not be rendered.</div>';
     $settings = array();
     $settings['type'] = 'page';
-    $settings['title'] = 'Test entity embed with entity_reference:entity_reference_entity_id display plugin';
+    $settings['title'] = 'Test entity_reference:entity_reference_entity_id Entity Embed Display plugin';
     $settings['body'] = array(array('value' => $content, 'format' => 'custom_format'));
     $node = $this->drupalCreateNode($settings);
     $this->drupalGet('node/' . $node->id());
@@ -114,11 +114,11 @@ class EntityReferenceFieldFormatterTest extends EntityEmbedTestBase {
     $this->assertNoText(strip_tags($content), 'Placeholder does not appears in the output when embed is successful.');
     $this->assertNoLinkByHref('node/' . $this->node->id(), 'Link to the embedded node does not exists.');
 
-    // Test entity embed using 'Rendered entity' display plugin.
+    // Test 'Rendered entity' Entity Embed Display plugin.
     $content = '<div data-entity-type="node" data-entity-uuid="' . $this->node->uuid() . '" data-entity-embed-display="entity_reference:entity_reference_entity_view" data-entity-embed-settings=\'{"view_mode":"teaser"}\'>This placeholder should not be rendered.</div>';
     $settings = array();
     $settings['type'] = 'page';
-    $settings['title'] = 'Test entity embed with entity_reference:entity_reference_label display plugin';
+    $settings['title'] = 'Test entity_reference:entity_reference_label Entity Embed Display plugin';
     $settings['body'] = array(array('value' => $content, 'format' => 'custom_format'));
     $node = $this->drupalCreateNode($settings);
     $this->drupalGet('node/' . $node->id());
diff --git a/src/Tests/FileFieldFormatterTest.php b/src/Tests/FileFieldFormatterTest.php
index 5791fe7..c77fc44 100644
--- a/src/Tests/FileFieldFormatterTest.php
+++ b/src/Tests/FileFieldFormatterTest.php
@@ -38,7 +38,7 @@ class FileFieldFormatterTest extends EntityEmbedTestBase {
   }
 
   /**
-   * Tests file field formatter display plugins.
+   * Tests file field formatter Entity Embed Display plugins.
    */
   public function testFileFieldFormatter() {
     // Ensure that file field formatters are available as plugins.
@@ -69,7 +69,7 @@ class FileFieldFormatterTest extends EntityEmbedTestBase {
       $this->assertIdentical((string) $conf_form['description']['#title'], 'Description');
     }
 
-    // Test entity embed using 'Generic file' display plugin.
+    // Test entity embed using 'Generic file' Entity Embed Display plugin.
     $embed_settings = array('description' => "This is sample description");
     $content = '<div data-entity-type="file" data-entity-uuid="' . $this->file->uuid() . '" data-entity-embed-display="file:file_default" data-entity-embed-settings=\'' . Json::encode($embed_settings) . '\'>This placeholder should not be rendered.</div>';
     $settings = array();
diff --git a/src/Tests/ImageFieldFormatterTest.php b/src/Tests/ImageFieldFormatterTest.php
index 19312a0..f290936 100644
--- a/src/Tests/ImageFieldFormatterTest.php
+++ b/src/Tests/ImageFieldFormatterTest.php
@@ -46,7 +46,7 @@ class ImageFieldFormatterTest extends EntityEmbedTestBase {
   }
 
   /**
-   * Tests image field formatter display plugin.
+   * Tests image field formatter Entity Embed Display plugin.
    */
   public function testImageFieldFormatter() {
     // Ensure that image field formatters are available as plugins.
@@ -81,7 +81,7 @@ class ImageFieldFormatterTest extends EntityEmbedTestBase {
     $this->assertIdentical($conf_form['title']['#type'], 'textfield');
     $this->assertIdentical((string) $conf_form['title']['#title'], 'Title');
 
-    // Test entity embed using 'Image' display plugin.
+    // Test entity embed using 'Image' Entity Embed Display plugin.
     $alt_text = "This is sample description";
     $title = "This is sample title";
     $embed_settings = array('image_link' => 'file');
diff --git a/src/Twig/EntityEmbedTwigExtension.php b/src/Twig/EntityEmbedTwigExtension.php
index 57d5348..9a77392 100644
--- a/src/Twig/EntityEmbedTwigExtension.php
+++ b/src/Twig/EntityEmbedTwigExtension.php
@@ -58,9 +58,10 @@ class EntityEmbedTwigExtension extends \Twig_Extension {
    * @param string $entity_id
    *   The entity ID or entity UUID.
    * @param string $display_plugin
-   *   (optional) The display plugin to be used to render the entity.
+   *   (optional) The Entity Embed Display plugin to be used to render the
+   *   entity.
    * @param array $display_settings
-   *   (optional) A list of settings for the display plugin.
+   *   (optional) A list of settings for the Entity Embed Display plugin.
    *
    * @return array
    *   A render array from entity_view().
diff --git a/tests/modules/entity_embed_test/src/EntityEmbedTestTwigController.php b/tests/modules/entity_embed_test/src/EntityEmbedTestTwigController.php
index e17a329..3267dba 100644
--- a/tests/modules/entity_embed_test/src/EntityEmbedTestTwigController.php
+++ b/tests/modules/entity_embed_test/src/EntityEmbedTestTwigController.php
@@ -24,7 +24,7 @@ class EntityEmbedTestTwigController {
   }
 
   /**
-   * Menu callback for testing entity_embed twig extension using 'label' display plugin.
+   * Menu callback for testing entity_embed twig extension using 'label' Entity Embed Display plugin.
    */
   public function labelPluginRender() {
     return array(
@@ -36,7 +36,7 @@ class EntityEmbedTestTwigController {
   }
 
   /**
-   * Menu callback for testing entity_embed twig extension using 'label' display plugin without linking to the node.
+   * Menu callback for testing entity_embed twig extension using 'label' Entity Embed Display plugin without linking to the node.
    */
   public function labelPluginNoLinkRender() {
     return array(
diff --git a/tests/modules/entity_embed_test/templates/entity_embed_twig_test.html.twig b/tests/modules/entity_embed_test/templates/entity_embed_twig_test.html.twig
index cf1a385..88c6e6e 100644
--- a/tests/modules/entity_embed_test/templates/entity_embed_twig_test.html.twig
+++ b/tests/modules/entity_embed_test/templates/entity_embed_twig_test.html.twig
@@ -5,7 +5,8 @@
   * Available variables:
   * - entity_type: Machine name of the entity type.
   * - id: ID or UUID of the entity to be embedded.
-  * - display_plugin: Machine name of the display plugin.
-  * - display_settings: An array of settings to be passed to the selected plugin.
+  * - display_plugin: Machine name of the Entity Embed Display plugin.
+  * - display_settings: An array of settings to be passed to the selected Entity
+  *   Embed Display plugin.
 #}
 {{ entity_embed(entity_type, id, display_plugin, display_settings) }}

diff --git a/src/Plugin/EmbedType/Entity.php b/src/Plugin/EmbedType/Entity.php
index 95482c5..0d8ffb9 100644
--- a/src/Plugin/EmbedType/Entity.php
+++ b/src/Plugin/EmbedType/Entity.php
@@ -51,7 +51,7 @@ class Entity extends EmbedTypeBase implements ContainerFactoryPluginInterface {
   protected $entityTypeBundleInfo;
 
   /**
    * The display plugin manager.
    *
    * @var \Drupal\entity_embed\EntityEmbedDisplay\EntityEmbedDisplayManager
    */
@@ -143,10 +143,10 @@ class Entity extends EmbedTypeBase implements ContainerFactoryPluginInterface {
       );
       $form['bundles']['#access'] = !empty($form['bundles']['#options']);
 
       // Allow option to limit display plugins.
       $form['display_plugins'] = array(
         '#type' => 'checkboxes',
-        '#title' => $this->t('Allowed display plugins'),
+        '#title' => $this->t('Allowed Entity Embed Display plugins'),
         '#options' => $this->displayPluginManager->getDefinitionOptionsForEntityType($entity_type_id),
         '#default_value' => $this->getConfigurationValue('display_plugins'),
         '#description' => $this->t('If none are selected, all are allowed. Note that these are the plugins which are allowed for this entity type, all of these might not be available for the selected entity.'),
@@ -202,7 +202,7 @@ class Entity extends EmbedTypeBase implements ContainerFactoryPluginInterface {
    * {@inheritdoc}
    */
   public function submitConfigurationForm(array &$form, FormStateInterface $form_state) {
     // Filter down the bundles and allowed display plugins.
     $bundles = $form_state->getValue('bundles');
     $form_state->setValue('bundles', array_keys(array_filter($bundles)));
     $display_plugins = $form_state->getValue('display_plugins');
@@ -232,7 +232,8 @@ class Entity extends EmbedTypeBase implements ContainerFactoryPluginInterface {
         if (!$this->entityTypeManager->getDefinition($entity_type_id)->hasViewBuilderClass()) {
           unset($options[$group][$entity_type_id]);
         }
         // Filter out entity types that will not have any display plugins.
         if (!$this->displayPluginManager->getDefinitionOptionsForEntityType($entity_type_id)) {
           unset($options[$group][$entity_type_id]);
         }
@@ -286,7 +287,7 @@ class Entity extends EmbedTypeBase implements ContainerFactoryPluginInterface {
       $this->addDependency($bundle_dependency['type'], $bundle_dependency['name']);
     }
 
     // Calculate display plugin dependencies.
     foreach ($this->getConfigurationValue('display_plugins') as $display_plugin) {
       $instance = $this->displayPluginManager->createInstance($display_plugin);
       $this->calculatePluginDependencies($instance);
@@ -51,7 +51,7 @@ class Entity extends EmbedTypeBase implements ContainerFactoryPluginInterface {
 
   /**
-   * The display plugin manager.
+   * The Entity Embed Display plugin manager.
    *
    * @var \Drupal\entity_embed\EntityEmbedDisplay\EntityEmbedDisplayManager
@@ -143,10 +143,10 @@ class Entity extends EmbedTypeBase implements ContainerFactoryPluginInterface {
       $form['bundles']['#access'] = !empty($form['bundles']['#options']);
 
-      // Allow option to limit display plugins.
+      // Allow option to limit Entity Embed Display plugins.
       $form['display_plugins'] = array(
         '#type' => 'checkboxes',
@@ -202,7 +202,7 @@ class Entity extends EmbedTypeBase implements ContainerFactoryPluginInterface {
    */
   public function submitConfigurationForm(array &$form, FormStateInterface $form_state) {
-    // Filter down the bundles and allowed display plugins.
+    // Filter down the bundles and allowed Entity Embed Display plugins.
     $bundles = $form_state->getValue('bundles');
     $form_state->setValue('bundles', array_keys(array_filter($bundles)));
@@ -232,7 +232,8 @@ class Entity extends EmbedTypeBase implements ContainerFactoryPluginInterface {
           unset($options[$group][$entity_type_id]);
         }
-        // Filter out entity types that will not have any display plugins.
+        // Filter out entity types that will not have any Entity Embed Display
+        // plugins.
         if (!$this->displayPluginManager->getDefinitionOptionsForEntityType($entity_type_id)) {
           unset($options[$group][$entity_type_id]);
@@ -286,7 +287,7 @@ class Entity extends EmbedTypeBase implements ContainerFactoryPluginInterface {
     }
 
-    // Calculate display plugin dependencies.
+    // Calculate display Entity Embed Display dependencies.
     foreach ($this->getConfigurationValue('display_plugins') as $display_plugin) {
       $instance = $this->displayPluginManager->createInstance($display_plugin);